/**
 * $Id: Config.java,v 1.2 2008/12/10 20:38:10 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 22.10.2008 by oliver (ob@oasd.de)
 */
package patterntesting.sample;

import java.io.*;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.LogFactoryImpl;

/**
 * This class is an example how NullPointerExceptions may happen.
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 22.10.2008
 * @version $Revision: 1.2 $
 */
public class Config {
    
    private static final Log log = LogFactoryImpl.getLog(Config.class);
    private static String propertyResource = "/default.properties";
    
    public static void setResource(String name) {
        propertyResource = name;
    }
    
    public static String getVersion() {
        return getProperty("version");
    }
    
    public static String getProperty(String name) {
        Properties properties = getProperties();
        return properties.getProperty(name);
    }
    
    public static Properties getProperties() {
        Properties properties = new Properties();
        try {
            properties.load(getPropertyStream());
            log.info(propertyResource + " loaded");
            return properties;
        } catch (Exception e) {
            log.warn("can't load properties", e);
            return null;
        }
    }
    
    public static InputStream getPropertyStream() {
        return Config.class.getResourceAsStream(propertyResource);
    }
    
    public static String getOS() {
        return System.getProperty("os.name");
    }
    
    public static String getJdkHome() {
        return System.getenv("JDK_HOME");
    }
    
    public static File getJdkHomeDir() {
        String jdkHome = getJdkHome();
        assert jdkHome != null;
        return new File(jdkHome);
    }

}

/**
 * $Log: Config.java,v $
 * Revision 1.2  2008/12/10 20:38:10  oboehm
 * one more example for an NPE added
 *
 * Revision 1.1  2008/11/08 18:44:52  oboehm
 * some samples how to use the PatternTesting libs
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-samples/src/main/java/patterntesting/sample/Config.java,v $
 */
